==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Önceki oyunu yüklemede hata. Yeni bir oyun başlatılacak.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>Geçen süre: %1</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 adım atıldı</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1/%2 hedef kaldı</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Durdu</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Süper</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Pencereler</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komut</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Kontrol</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Seçenek</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçin:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Önemli</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Değişikliklerin geçerli olabilmesi için bu uygulamayı tekrar başlatınız.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Yeni Oyun</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Avla ve Öldür</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Yığın</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Yığın 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Yığın 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Yığın 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Yığın 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritma:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Hedefler:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Avla ve Öldür</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Yığın</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Yığın 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Yığın 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Yığın 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Yığın 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Skor Tablosu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zaman</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Adımlar</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritma</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Tebrikler!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>İlk 10&apos;a girdiniz.
Lütfen adınızı girin:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Oyun</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>İzleri göster</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Adım sayısını göster</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Geçen süreyi göster</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Yumuşak ilerleme</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Yukarı:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Aşağı:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Sola:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Sağa:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>İz bayrağı:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temalar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Çıkar</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Tema Dosyasını Seçin</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Veri klasörü oluşturulamıyor.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Tema dosyası kopyalanamıyor.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Seçilen tema silinsin mi?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Seçilen tema kaldırılamadı.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Oyun</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Durdur</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;İpucu</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Yüksek Skorlar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çıkış</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Uzaklaştır</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Uygulama Dili...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Tercihler</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Bir Labirent Oyunudur</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Sürüm &lt;a href=%1&gt;GPL 3&lt;/a&gt; lisansı altındadır.</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>İkonlar &lt;a href=%1&gt;Oxygen&lt;/a&gt; temasındandır</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;LGPL 3&lt;/a&gt; lisansı altındadır</translation>
    </message>
</context>
</TS>

==> cutemaze_1.2.5.orig.tar.gz: cutemaze-1.2.5/translations/cutemaze_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Önceki oyunu yüklemede hata. Yeni bir oyun başlatılacak.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>Geçen süre: %1</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 adım atıldı</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1/%2 hedef kaldı</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Durdu</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Süper</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Pencereler</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komut</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Kontrol</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Seçenek</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçin:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Önemli</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Değişikliklerin geçerli olabilmesi için bu uygulamayı tekrar başlatınız.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Yeni Oyun</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Avla ve Öldür</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Yığın</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Yığın 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Yığın 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Yığın 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Yığın 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algoritma:</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Hedefler:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Avla ve Öldür</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Recursive Backtracker</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Yığın</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Yığın 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Yığın 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Yığın 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Yığın 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Skor Tablosu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Skor</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Zaman</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Adımlar</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algoritma</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Tebrikler!</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>İlk 10&apos;a girdiniz.
Lütfen adınızı girin:</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Oyun</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>İzleri göster</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Adım sayısını göster</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Geçen süreyi göster</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Yumuşak ilerleme</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Yukarı:</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Aşağı:</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Sola:</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Sağa:</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>İz bayrağı:</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Temalar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Çıkar</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Tema Dosyasını Seçin</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Üzgünüm</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Veri klasörü oluşturulamıyor.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Tema dosyası kopyalanamıyor.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Soru</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Seçilen tema silinsin mi?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Seçilen tema kaldırılamadı.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Oyun</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Yeni</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Durdur</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;İpucu</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Yüksek Skorlar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çıkış</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Yakınlaştır</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Uzaklaştır</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Uygulama Dili...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Tercihler</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Bir Labirent Oyunudur</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Sürüm &lt;a href=%1&gt;GPL 3&lt;/a&gt; lisansı altındadır.</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>İkonlar &lt;a href=%1&gt;Oxygen&lt;/a&gt; temasındandır</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>&lt;a href=%1&gt;LGPL 3&lt;/a&gt; lisansı altındadır</translation>
    </message>
</context>
</TS>
